SystemOrganization addCategory: #'Seaside-Tests-Development'!

TestCase subclass: #WADebugErrorHandlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WADebugErrorHandlerTest commentStamp: 'jf 9/19/2008 19:32' prior: 0!
This isn't really a unit test of WADebugErrorHandler but rather a test that tries to replicate a simple version of the same error handling behaviour upon which the error handler depends. The error handler itself would be hard to test because it opens a debugger as its first action.

This should at least help confirm that the assumptions that were in place when writing the handler on Squeak hold true on other platforms.!

!WADebugErrorHandlerTest methodsFor: 'private' stamp: 'jf 3/14/2009 01:11'!
handleException: anException debuggerSimulation: debugBlock
	debugBlock value.
	anException resume! !

!WADebugErrorHandlerTest methodsFor: 'private' stamp: 'jf 9/30/2009 00:19'!
simulateWithDebugBlock: debugBlock progress: desiredProgress result: desiredResult 
	"Set up a known working mechanism similar to the error handler so we can
	test whether the underlying system works the same way as on Squeak
	where WADebugErrorHandler was originally developed."
	| progress semaphore result |
	progress := OrderedCollection new.
	semaphore := GRPlatform current semaphoreClass new.
	
	[ 
	[ result := 
	[ progress add: #a.
	1 / 0.
	progress add: #b.
	#resumed ] 
		on: Error
		do: 
			[ :e | 
			progress add: #c.
			self 
				handleException: e
				debuggerSimulation: 
					[ progress add: #d.
					debugBlock value.
					progress add: #e ] ] ] ensure: [ semaphore signal ] ] fork.
	semaphore wait.
	self assert: progress asArray = desiredProgress asArray.
	self assert: result = desiredResult! !

!WADebugErrorHandlerTest methodsFor: 'tests' stamp: 'lr 7/25/2011 19:00'!
testMechanismAbort
	"Test if things behave as expected when simulating a Debugger being closed
	(in other words, the process being terminated)."

	self
		simulateWithDebugBlock: [ Processor activeProcess terminate ]
		progress: #(#a #c #d)
		result: nil! !

!WADebugErrorHandlerTest methodsFor: 'tests' stamp: 'lr 7/25/2011 19:00'!
testMechanismProceed
	"Test if things behave as expected when simulating a Debugger being proceeded
	(in other words, the process being terminated)."

	self
		simulateWithDebugBlock: [ nil ]
		progress: #(#a #c #d #e #b)
		result: #resumed! !

TestCase subclass: #WADevelopmentPlatformTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

TestCase subclass: #WAWalkbackTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WAWalkbackTest methodsFor: 'tests' stamp: 'lr 7/25/2011 19:05'!
testFrameCount
	| walkback |
	[ WATestError signal: 'foo' ]
		on: WATestError
		do: [ :e | walkback := WAWalkback current exception: e ].
	self assert: walkback frameCount > 0! !

WAContextTest subclass: #WAPrettyPrintedDocumentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WAPrettyPrintedDocumentTest methodsFor: 'testing' stamp: 'pmm 6/25/2011 19:47'!
assert: anObject rendersAs: aString
	| oldContext document newContext stream |
	stream := WriteStream on: String new.
	oldContext := WARenderContext new
		actionUrl: WAUrl new;
		document: (WAHtmlDocument on: stream);
		yourself.
	oldContext visitor: (WARenderingGuide client: (WARenderVisitor context: oldContext)).
	newContext := oldContext copy.
	newContext disableHalos.
	document := WAPrettyPrintedDocument context: oldContext.
	newContext document: document.
	(WARenderVisitor context: newContext) start: anObject. "from tools-web should be in dependency list"
	newContext document close.
	self assert: aString equals: stream contents! !

!WAPrettyPrintedDocumentTest methodsFor: 'testing' stamp: 'pmm 8/5/2011 23:13'!
testEventsInKnownEvents
	"Test that any event on WATagBrush is in WAPrettyPrintedDocument >> #knownEvents"
	| selectors eventNames knownEvents |
	selectors :=  WATagBrush selectors select: [ :each |
		(each beginsWithSubCollection: #on)
			and: [ each ~= #onEnter: ] ].
	eventNames := selectors collect: [ :each |
		each = #onDoubleClick:
			ifTrue: [ 'ondblclick' ]
			ifFalse: [ each allButLast asLowercase ] ].
	knownEvents := WAPrettyPrintedDocument basicNew knownEvents.
	eventNames do: [ :each |
		self assert: (knownEvents includes: each) ]! !

!WAPrettyPrintedDocumentTest methodsFor: 'testing' stamp: 'pmm 6/26/2011 14:20'!
testKnownEventsInTagBrush
	"Test that any event in WAPrettyPrintedDocument >> #knownEvents is on WATagBrush"
	| knownEvents |
	knownEvents := WAPrettyPrintedDocument basicNew knownEvents.
	knownEvents do: [ :each |
		| selector |
		selector := each = 'ondblclick'
			ifTrue: [ #onDoubleClick: ]
			ifFalse: [
				WATagBrush selectors detect: [ :eachSelector |
				eachSelector allButLast asLowercase greaseString = each ] ].
		self assert: selector notNil ]! !

!WAPrettyPrintedDocumentTest methodsFor: 'testing' stamp: 'pmm 2/18/2011 21:53'!
testRendering
	self
		assert: WAPrettyPrintedDocumentTestComponent new
		rendersAs: '&lt;<span class="wa-tag">h1</span>&nbsp;<span class="wa-attribute-key">title</span>=<span class="wa-attribute-value">&quot;&amp;amp;foo;&quot;</span>&gt;&amp;amp;foo;&lt;/<span class="wa-tag">h1</span>&gt;&amp;nbsp;'! !

WAComponent subclass: #WAPrettyPrintedDocumentTestComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Development'!

!WAPrettyPrintedDocumentTestComponent methodsFor: 'rendering' stamp: 'pmm 2/18/2011 21:53'!
renderContentOn: html
	html heading
		title: '&foo;';
		with: '&foo;'.
	html space! !

!GRPackage class methodsFor: '*seaside-tests-development' stamp: 'lr 2/17/2010 15:13'!
seasideTestsDevelopment
	^ self new
		name: 'Seaside-Tests-Development';
		description: 'Unit tests for the package Seaside-Development.';
		addDependency: 'Seaside-Development';
		addDependency: 'Seaside-Tests-Tools-Web';
		url: #seasideUrl;
		yourself! !
